IsolateSimulationEngine class

Implemented types

Constructors

IsolateSimulationEngine({EngineBackend backend = EngineBackend.auto, String? rustLibraryPath})

Properties

backend EngineBackend
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rustLibraryPath String?
final

Methods

applyEdit(BodyEdit edit) Future<void>
Applies a body create/update/delete edit.
override
dispose() Future<void>
Disposes engine resources.
override
getState() SimulationState
Returns current simulation state.
override
initialize({required SimulationConfig config, required List<SimulationBody> bodies}) Future<void>
Initializes engine state from a config and starting bodies.
override
loadScenario(ScenarioModel scenario) Future<void>
Loads a complete scenario document.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreSnapshot(SnapshotModel snapshot) Future<void>
Restores simulation from a snapshot.
override
saveScenario() Future<ScenarioModel>
Saves current state as a scenario.
override
setConfig(SimulationConfig config) Future<void>
Applies a new simulation configuration.
override
snapshot() Future<SnapshotModel>
Creates a point-in-time snapshot.
override
step(int ticks) Future<StepSummary>
Advances the simulation by ticks.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited