SimulationEngine class abstract

Common runtime interface implemented by all simulation backends.

Implementers

Constructors

SimulationEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyEdit(BodyEdit edit) Future<void>
Applies a body create/update/delete edit.
dispose() Future<void>
Disposes engine resources.
getState() SimulationState
Returns current simulation state.
initialize({required SimulationConfig config, required List<SimulationBody> bodies}) Future<void>
Initializes engine state from a config and starting bodies.
loadScenario(ScenarioModel scenario) Future<void>
Loads a complete scenario document.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreSnapshot(SnapshotModel snapshot) Future<void>
Restores simulation from a snapshot.
saveScenario() Future<ScenarioModel>
Saves current state as a scenario.
setConfig(SimulationConfig config) Future<void>
Applies a new simulation configuration.
snapshot() Future<SnapshotModel>
Creates a point-in-time snapshot.
step(int ticks) Future<StepSummary>
Advances the simulation by ticks.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited